==> taomu-job-server-0.0.13.4-sources.jar: cool/taomu/box/job/server/dao/TaskDao.java <==
/**
 * Copyright (c) 2023 murenchao
 * taomu is licensed under Mulan PubL v2.
 * You can use this software according to the terms and conditions of the Mulan PubL v2.
 * You may obtain a copy of Mulan PubL v2 at:
 *       http://license.coscl.org.cn/MulanPubL-2.0
 * THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 * EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 * MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 * See the Mulan PubL v2 for more details.
 */
package cool.taomu.box.job.server.dao;

import cool.taomu.box.job.server.dao.provider.TaskDaoProvider;
import cool.taomu.box.job.server.entity.TaskEntity;
import java.util.List;
import org.apache.ibatis.annotations.Delete;
import org.apache.ibatis.annotations.InsertProvider;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Result;
import org.apache.ibatis.annotations.Select;
import org.apache.ibatis.type.JdbcType;

@Mapper
@SuppressWarnings("all")
public interface TaskDao {
  @Result(property = "taskId", column = "task_id", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "taskName", column = "task_name", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "schedule", column = "schedule", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "isScheduledTask", column = "is_schedule_task", javaType = Boolean.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "parameter", column = "parameter", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "shellPath", column = "shell_path", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "taskVersion", column = "task_version", javaType = Integer.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "htmlTemplate", column = "html_template", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "runTimestamp", column = "run_timestamp", javaType = Long.class, jdbcType = JdbcType.TIMESTAMP)
  @Result(property = "taskAddTimestmap", column = "TASK_ADD_TIMESTAMP", javaType = Long.class, jdbcType = JdbcType.TIMESTAMP)
  @Result(property = "clientId", column = "client_id", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "type", column = "type", javaType = Integer.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "shellType", column = "shell_type", javaType = Integer.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "status", column = "STATUS", javaType = Integer.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "taskDirectory", column = "TASK_DIRECTORY", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "extendColumn", column = "EXTEND_COLUMN", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "resultPath", column = "result_path", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Select("select * from TAOMUBOX_JOB_TASK where task_id=#{taskId}")
  TaskEntity getOneTask(@Param("taskId") final String taskId);
  
  @Result(property = "taskId", column = "task_id", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "resultPath", column = "result_path", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "taskName", column = "task_name", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "schedule", column = "schedule", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "isScheduledTask", column = "is_schedule_task", javaType = Boolean.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "parameter", column = "parameter", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "shellPath", column = "shell_Path", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "taskVersion", column = "task_version", javaType = Integer.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "htmlTemplate", column = "html_template", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "taskDirectory", column = "TASK_DIRECTORY", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "extendColumn", column = "EXTEND_COLUMN", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "runTimestamp", column = "run_timestamp", javaType = Long.class, jdbcType = JdbcType.TIMESTAMP)
  @Result(property = "taskAddTimestmap", column = "TASK_ADD_TIMESTAMP", javaType = Long.class, jdbcType = JdbcType.TIMESTAMP)
  @Result(property = "clientId", column = "client_id", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "type", column = "type", javaType = Integer.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "shellType", column = "shell_type", javaType = Integer.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "status", column = "STATUS", javaType = Integer.class, jdbcType = JdbcType.INTEGER)
  @Select("select * from TAOMUBOX_JOB_TASK where task_name=#{taskName}")
  TaskEntity getOneTaskByTaskName(@Param("taskName") final String taskName);
  
  @Result(property = "taskId", column = "task_id", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "taskName", column = "task_name", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "schedule", column = "schedule", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "isScheduledTask", column = "is_schedule_task", javaType = Boolean.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "parameter", column = "parameter", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "shellPath", column = "shell_path", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "taskVersion", column = "task_version", javaType = Integer.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "htmlTemplate", column = "html_template", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "extendColumn", column = "EXTEND_COLUMN", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "taskDirectory", column = "TASK_DIRECTORY", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "runTimestamp", column = "run_timestamp", javaType = Long.class, jdbcType = JdbcType.TIMESTAMP)
  @Result(property = "taskAddTimestmap", column = "TASK_ADD_TIMESTAMP", javaType = Long.class, jdbcType = JdbcType.TIMESTAMP)
  @Result(property = "clientId", column = "client_id", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "type", column = "type", javaType = Integer.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "shellType", column = "shell_type", javaType = Integer.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "status", column = "STATUS", javaType = Integer.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "resultPath", column = "result_path", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Select("select * from TAOMUBOX_JOB_TASK")
  List<TaskEntity> getTaskAll();
  
  @InsertProvider(type = TaskDaoProvider.class, method = "insert")
  int saveTask(@Param("t") final TaskEntity entity);
  
  @Delete("delete from TAOMUBOX_JOB_TASK where task_id=#{taskId}")
  int deleteOneTask(@Param("taskId") final String taskId);
}

==> taomu-job-server-0.0.15.2-sources.jar: cool/taomu/box/job/server/dao/TaskDao.java <==
/**
 * Copyright (c) 2023 murenchao
 * taomu is licensed under Mulan PubL v2.
 * You can use this software according to the terms and conditions of the Mulan PubL v2.
 * You may obtain a copy of Mulan PubL v2 at:
 *       http://license.coscl.org.cn/MulanPubL-2.0
 * THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 * EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 * MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 * See the Mulan PubL v2 for more details.
 */
package cool.taomu.box.job.server.dao;

import cool.taomu.box.job.server.dao.provider.TaskDaoProvider;
import cool.taomu.box.job.server.entity.TaskEntity;
import java.util.List;
import org.apache.ibatis.annotations.Delete;
import org.apache.ibatis.annotations.InsertProvider;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Result;
import org.apache.ibatis.annotations.Select;
import org.apache.ibatis.type.JdbcType;

@Mapper
@SuppressWarnings("all")
public interface TaskDao {
  @Result(property = "taskId", column = "task_id", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "taskName", column = "task_name", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "schedule", column = "schedule", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "isScheduledTask", column = "is_schedule_task", javaType = Boolean.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "parameter", column = "parameter", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "shellPath", column = "shell_path", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "taskVersion", column = "task_version", javaType = Integer.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "htmlTemplate", column = "html_template", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "runTimestamp", column = "run_timestamp", javaType = Long.class, jdbcType = JdbcType.TIMESTAMP)
  @Result(property = "taskAddTimestmap", column = "TASK_ADD_TIMESTAMP", javaType = Long.class, jdbcType = JdbcType.TIMESTAMP)
  @Result(property = "clientId", column = "client_id", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "type", column = "type", javaType = Integer.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "shellType", column = "shell_type", javaType = Integer.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "status", column = "STATUS", javaType = Integer.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "taskDirectory", column = "TASK_DIRECTORY", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "extendColumn", column = "EXTEND_COLUMN", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "exceptionInfo", column = "exception_info", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Select("select * from TAOMUBOX_JOB_TASK where task_id=#{taskId}")
  TaskEntity getOneTask(@Param("taskId") final String taskId);
  
  @Result(property = "taskId", column = "task_id", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "exceptionInfo", column = "exception_info", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "taskName", column = "task_name", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "schedule", column = "schedule", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "isScheduledTask", column = "is_schedule_task", javaType = Boolean.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "parameter", column = "parameter", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "shellPath", column = "shell_Path", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "taskVersion", column = "task_version", javaType = Integer.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "htmlTemplate", column = "html_template", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "taskDirectory", column = "TASK_DIRECTORY", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "extendColumn", column = "EXTEND_COLUMN", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "runTimestamp", column = "run_timestamp", javaType = Long.class, jdbcType = JdbcType.TIMESTAMP)
  @Result(property = "taskAddTimestmap", column = "TASK_ADD_TIMESTAMP", javaType = Long.class, jdbcType = JdbcType.TIMESTAMP)
  @Result(property = "clientId", column = "client_id", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "type", column = "type", javaType = Integer.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "shellType", column = "shell_type", javaType = Integer.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "status", column = "STATUS", javaType = Integer.class, jdbcType = JdbcType.INTEGER)
  @Select("select * from TAOMUBOX_JOB_TASK where task_name=#{taskName}")
  TaskEntity getOneTaskByTaskName(@Param("taskName") final String taskName);
  
  @Result(property = "taskId", column = "task_id", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "taskName", column = "task_name", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "schedule", column = "schedule", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "isScheduledTask", column = "is_schedule_task", javaType = Boolean.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "parameter", column = "parameter", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "shellPath", column = "shell_path", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "taskVersion", column = "task_version", javaType = Integer.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "htmlTemplate", column = "html_template", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "extendColumn", column = "EXTEND_COLUMN", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "taskDirectory", column = "TASK_DIRECTORY", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "runTimestamp", column = "run_timestamp", javaType = Long.class, jdbcType = JdbcType.TIMESTAMP)
  @Result(property = "taskAddTimestmap", column = "TASK_ADD_TIMESTAMP", javaType = Long.class, jdbcType = JdbcType.TIMESTAMP)
  @Result(property = "clientId", column = "client_id", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Result(property = "type", column = "type", javaType = Integer.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "shellType", column = "shell_type", javaType = Integer.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "status", column = "STATUS", javaType = Integer.class, jdbcType = JdbcType.INTEGER)
  @Result(property = "exceptionInfo", column = "exception_info", javaType = String.class, jdbcType = JdbcType.VARCHAR)
  @Select("select * from TAOMUBOX_JOB_TASK")
  List<TaskEntity> getTaskAll();
  
  @InsertProvider(type = TaskDaoProvider.class, method = "insert")
  int saveTask(@Param("t") final TaskEntity entity);
  
  @Delete("delete from TAOMUBOX_JOB_TASK where task_id=#{taskId}")
  int deleteOneTask(@Param("taskId") final String taskId);
}
